from setuptools import setup

setup(name='biosignal',
      version='0.0.2',
      description="""A library for processing and analysing physiological
      signals such as ECG, BP, EMG, EEG, Pulse and Sp02""",
      url='http://github.com/EmlynC/python-biosignal',
      author='Emlyn Clay',
      author_email='eclay101@gmail.com',
      license='MIT',
      packages=['biosignal'],
      zip_safe=False)